==> ace_5.4.7.orig.tar.gz: ACE_wrappers/TAO/orbsvcs/orbsvcs/PortableGroup/PG_Object_Adapter_Factory.cpp <==
// PG_Object_Adapter_Factory.cpp,v 1.3 2005/03/07 14:10:49 jwillemsen Exp

#include "PG_Object_Adapter_Factory.h"
#include "PG_Servant_Dispatcher.h"

#include "tao/PortableServer/Object_Adapter.h"
#include "tao/ORB_Core.h"

ACE_RCSID (TAO_PortableGroup,
           PG_Object_Adapter_Factory,
           "PG_Object_Adapter_Factory.cpp,v 1.3 2005/03/07 14:10:49 jwillemsen Exp")


TAO_PG_Object_Adapter_Factory::TAO_PG_Object_Adapter_Factory (void)
{
}

TAO_Adapter*
TAO_PG_Object_Adapter_Factory::create (TAO_ORB_Core *orb_core)
{
  TAO_Object_Adapter *object_adapter = 0;
  ACE_NEW_RETURN (object_adapter,
                  TAO_Object_Adapter (orb_core->server_factory ()->
                                        active_object_map_creation_parameters (),
                                      *orb_core),
                  0);

  // Create and register the RT servant dispatcher.
  TAO_PG_Servant_Dispatcher *rt_servant_dispatcher = 0;
  ACE_NEW_RETURN (rt_servant_dispatcher,
                  TAO_PG_Servant_Dispatcher,
                  0);
  object_adapter->servant_dispatcher (rt_servant_dispatcher);


  return object_adapter;
}

ACE_FACTORY_DEFINE (TAO_PortableGroup, TAO_PG_Object_Adapter_Factory)
ACE_STATIC_SVC_DEFINE (TAO_PG_Object_Adapter_Factory,
                       ACE_TEXT ("TAO_GOA"),
                       ACE_SVC_OBJ_T,
                       &ACE_SVC_NAME (TAO_PG_Object_Adapter_Factory),
                       ACE_Service_Type::DELETE_THIS | ACE_Service_Type::DELETE_OBJ,
                       0)

==> ace_5.7.7+dfsg.orig.tar.gz: ACE_wrappers/TAO/orbsvcs/orbsvcs/PortableGroup/PG_Object_Adapter_Factory.cpp <==
// $Id: PG_Object_Adapter_Factory.cpp 71526 2006-03-14 06:14:35Z jtc $

#include "orbsvcs/PortableGroup/PG_Object_Adapter_Factory.h"
#include "orbsvcs/PortableGroup/PG_Servant_Dispatcher.h"

#include "tao/PortableServer/Object_Adapter.h"
#include "tao/ORB_Core.h"

ACE_RCSID (TAO_PortableGroup,
           PG_Object_Adapter_Factory,
           "$Id: PG_Object_Adapter_Factory.cpp 71526 2006-03-14 06:14:35Z jtc $")

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

TAO_PG_Object_Adapter_Factory::TAO_PG_Object_Adapter_Factory (void)
{
}

TAO_Adapter*
TAO_PG_Object_Adapter_Factory::create (TAO_ORB_Core *orb_core)
{
  TAO_Object_Adapter *object_adapter = 0;
  ACE_NEW_RETURN (object_adapter,
                  TAO_Object_Adapter (orb_core->server_factory ()->
                                        active_object_map_creation_parameters (),
                                      *orb_core),
                  0);

  // Create and register the RT servant dispatcher.
  TAO_PG_Servant_Dispatcher *rt_servant_dispatcher = 0;
  ACE_NEW_RETURN (rt_servant_dispatcher,
                  TAO_PG_Servant_Dispatcher,
                  0);
  object_adapter->servant_dispatcher (rt_servant_dispatcher);


  return object_adapter;
}

TAO_END_VERSIONED_NAMESPACE_DECL

ACE_FACTORY_DEFINE (TAO_PortableGroup, TAO_PG_Object_Adapter_Factory)
ACE_STATIC_SVC_DEFINE (TAO_PG_Object_Adapter_Factory,
                       ACE_TEXT ("TAO_GOA"),
                       ACE_SVC_OBJ_T,
                       &ACE_SVC_NAME (TAO_PG_Object_Adapter_Factory),
                       ACE_Service_Type::DELETE_THIS | ACE_Service_Type::DELETE_OBJ,
                       0)
